ProSHADE: Class Members

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Here is a list of all documented class members with links to the class documentation for each member:

### - y -

- yAxisOrder : ProSHADE_internal_data::ProSHADE_data
- yAxisOrigin : ProSHADE_internal_data::ProSHADE_data
- yAxisOriginOriginal : ProSHADE_internal_data::ProSHADE_data
- yCom : ProSHADE_internal_data::ProSHADE_data
- yDimIndices : ProSHADE_internal_data::ProSHADE_data
- yDimIndicesOriginal : ProSHADE_internal_data::ProSHADE_data
- yDimSize : ProSHADE_internal_data::ProSHADE_data
- yDimSizeOriginal : ProSHADE_internal_data::ProSHADE_data
- yFrom : ProSHADE_internal_data::ProSHADE_data
- yGridIndices : ProSHADE_internal_data::ProSHADE_data
- yTo : ProSHADE_internal_data::ProSHADE_data